<?php

declare(strict_types=1);

/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package Product Availability Status Base for Magento 2
 */

namespace Amasty\Stockstatus\Observer;

use Amasty\Stockstatus\Model\ConfigProvider;
use Magento\Catalog\Api\Data\ProductInterface;
use Magento\Catalog\Model\Product;
use Magento\Framework\Event\Observer;
use Magento\Framework\Event\ObserverInterface;

/**
 * We need this observer to compatibility with Amasty Preorder Module
 */
class ModifyOriginalNote implements ObserverInterface
{
    /**
     * @var ConfigProvider
     */
    private $configProvider;

    public function __construct(ConfigProvider $configProvider)
    {
        $this->configProvider = $configProvider;
    }

    public function execute(Observer $observer): void
    {
        $originalNoteEventObject = $observer->getData('data_object');
        if (empty($originalNoteEventObject)) {
            return;
        }

        $originalNote = $originalNoteEventObject->getData('original_note');
        /** @var ProductInterface $product */
        $product = $originalNoteEventObject->getData('product');
        if (empty($originalNote) || empty($product) || $product->getTypeId() !== Product\Type::TYPE_BUNDLE) {
            return;
        }

        $stockStatusInformation = $product->getExtensionAttributes()->getStockstatusInformation();
        if (empty($stockStatusInformation)) {
            return;
        }

        $customStockStatus = $stockStatusInformation->getStatusMessage();
        if (empty($customStockStatus)) {
            return;
        }

        if ($this->configProvider->isShowDefaultStatus()) {
            $originalNoteEventObject->setData(
                'original_note',
                sprintf('%s %s', $originalNote, $customStockStatus)
            );
        } else {
            $originalNoteEventObject->setData('original_note', $customStockStatus);
        }
    }
}
